try:
    import unittest2 as unittest
except ImportError:
    import unittest

from datatree import Tree

class test_Tree(unittest.TestCase):
    pass # TODO: Revisit. Does this need its own tests?
